@@ -1,8 +1,10 @@
 from aenum import NamedConstant
+
 from ...__share__ import classproperty
 
 __all__ = ["tokenise_line", "Prefix", "Suffix", "Node"]
 
+
 def has_precedent(seen, prefix):
     """
     Check if there is a seen node with a given prefix.
@@ -29,7 +31,7 @@ def tokenise_line(line, line_no, block_no, seen=None, config=None):
     specify `custom_config` dict to override defaults from
     `lever_config_dict`.
     """
-    ############ Begin config instantation ###########
+    # Begin config instantation
     default_config = lever_config_dict()
     if config:
         # Only allow custom config keys also present in default_config dict
@@ -37,13 +39,15 @@ def tokenise_line(line, line_no, block_no, seen=None, config=None):
         config = {**default_config, **config}  # override default config
     else:
         config = default_config
-    ############## Read config variables ##############
+    # Read config variables
     # TODO: just read into locals if config gets any more complicated
     ALLOW_LIST_WITHOUT_SUFFIX_INIT = config.get("ALLOW_LIST_WITHOUT_SUFFIX_INIT")
-    ############# End config instantation #############
+    # End config instantation
     seen = seen if seen else []  # avoid default mutable arg gotcha
     penultimate = seen[-1] if seen else None  # directly preceding
-    node = Node(prefix=None, contents=line, suffix=None, line_no=line_no, block_no=block_no)
+    node = Node(
+        prefix=None, contents=line, suffix=None, line_no=line_no, block_no=block_no
+    )
     if line == "":
         node.prefix = Prefix.BlankNode
     elif line.startswith("-:"):
@@ -87,10 +91,10 @@ def tokenise_line(line, line_no, block_no, seen=None, config=None):
         elif line[2] == ",":
             node.prefix = Prefix.ContDesc
     elif line.startswith("-#"):
-        max_header = 8 # 1-based count of header levels
+        max_header = 8  # 1-based count of header levels
         start_at = len(Prefix.Header1.str)
         confirmed_levels = 1
-        for i,l in enumerate(line[start_at : start_at + max_header]):
+        for i, l in enumerate(line[start_at : start_at + max_header]):
             if l != "#":
                 break
             else:
@@ -120,7 +124,7 @@ class Affix(NamedConstant):
         IN: the string matched by the token. OUT: the node name or
         a list of names if the token name is not unique.
         """
-        matches = cls.tokseq2name_multidict.get(tok)
+        matched = cls.tokseq2name_multidict.get(tok)
         if matched:
             if len(matched) == 1:
                 [matched] = matched
@@ -128,8 +132,8 @@ class Affix(NamedConstant):
             raise KeyError(f"{tok} not a valid Affix token sequence")
         return matched
 
-    #@classproperty
-    #def tokseq2name_dict(cls):
+    # @classproperty
+    # def tokseq2name_dict(cls):
     #    "KEY: the string matched by the token. VAL: the node name."
     #    # N.B. does not assume the token-matching string is unique
     #    d = {k: v._value_ for k,v in Prefix.__members__.items()}
@@ -140,13 +144,11 @@ class Affix(NamedConstant):
         "KEY: the string matched by the token(s). VAL: list of node name(s)."
         # N.B. does not assume the token-matching string is unique
         d = {
-                v._value_: [
-                    k
-                    for k in cls._members_
-                    if cls._members_.get(k)._value_ == v._value_
-                ]
-                for v in cls._members_.values()
-            }
+            v._value_: [
+                k for k in cls._members_ if cls._members_.get(k)._value_ == v._value_
+            ]
+            for v in cls._members_.values()
+        }
         return d
 
     @classmethod
@@ -190,15 +192,15 @@ class Prefix(Affix):
     Therefore = "-:."  # E
     Because = "-:'"  # F
     SectBreak = "-~==~-"  # G_
-    Header1 = "-#" # Ha
-    Header2 = "-##" # Hb
-    Header3 = "-###" # Hc
-    Header4 = "-####" # Hd
-    Header5 = "-#####" # He
-    Header6 = "-######" # Hf
-    Header7 = "-#######" # Hg
-    Header8 = "-########" # Hh
-    BlankNode = "" # Z_
+    Header1 = "-#"  # Ha
+    Header2 = "-##"  # Hb
+    Header3 = "-###"  # Hc
+    Header4 = "-####"  # Hd
+    Header5 = "-#####"  # He
+    Header6 = "-######"  # Hf
+    Header7 = "-#######"  # Hg
+    Header8 = "-########"  # Hh
+    BlankNode = ""  # Z_
 
 
 class Suffix(Affix):
@@ -208,13 +210,16 @@ class Suffix(Affix):
 
     InitList = ":"
 
+
 class Node:
     """
     Provide a simple string-repr while storing the Prefix and Suffix
     as properties (intervening `contents` is just a string for now).
     """
 
-    def __init__(self, prefix=None, contents=None, suffix=None, line_no=None, block_no=None):
+    def __init__(
+        self, prefix=None, contents=None, suffix=None, line_no=None, block_no=None
+    ):
         self.prefix = prefix
         self.contents = contents
         self.suffix = suffix
